@@ -6,5 +6,9 @@ class APIError(Exception):
         return self.msg
 
 
-class InvalidAPIKeyError(APIError):
-    pass
+class InvalidAPIKeyError(Exception):
+    def __init__(self, msg):
+        self.msg = msg
+
+    def __str__(self):
+        return self.msg
